@@ -15,4 +15,6 @@ from .list import (OrderedList, UnorderedList, ListItem, DescriptionList,
                    DescriptionDefinition, DescriptionTerm)
 from .structure import (Section, Article, Navigation, Aside, Header, Footer,
                         Heading)
+from .table import (Table, TableHead, TableBody, TableRow, TableCell,
+                    ColumnGroup, Column)
 from .time import Time
